cruft
_________________

[![PyPI version](https://badge.fury.io/py/cruft.svg)](http://badge.fury.io/py/cruft)
[![Build Status](https://travis-ci.org/timothycrosley/cruft.svg?branch=master)](https://travis-ci.org/timothycrosley/cruft)
[![codecov](https://codecov.io/gh/timothycrosley/cruft/branch/master/graph/badge.svg)](https://codecov.io/gh/timothycrosley/cruft)
[![Join the chat at https://gitter.im/timothycrosley/cruft](https://badges.gitter.im/timothycrosley/cruft.svg)](https://gitter.im/timothycrosley/cruft?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![License](https://img.shields.io/github/license/mashape/apistatus.svg)](https://pypi.python.org/pypi/cruft/)
[![Downloads](https://pepy.tech/badge/cruft)](https://pepy.tech/project/cruft)
_________________

[Read Latest Documentation](https://timothycrosley.github.io/cruft/) - [Browse GitHub Code Repository](https://github.com/timothycrosley/cruft/)
_________________

**cruft** Allows you to maintain all the necessary cruft for packaging and building projects separate from the code you intentionally write. Built on-top of CookieCutter.
